aboutsummaryrefslogtreecommitdiff
path: root/src/lua/modules/keyboard/keyboard.cpp
diff options
context:
space:
mode:
authorchai <chaifix@163.com>2018-10-20 16:18:11 +0800
committerchai <chaifix@163.com>2018-10-20 16:18:11 +0800
commitcf68d9f46da1cf20503a7d738da1f43de916004d (patch)
tree5577e44d926deadb15ef5ca145e705eae14636fe /src/lua/modules/keyboard/keyboard.cpp
parente9410bd371fc68169c57d2c52382948a0b083da4 (diff)
*格式化代码
Diffstat (limited to 'src/lua/modules/keyboard/keyboard.cpp')
-rw-r--r--src/lua/modules/keyboard/keyboard.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/lua/modules/keyboard/keyboard.cpp b/src/lua/modules/keyboard/keyboard.cpp
index e384671..22bba0d 100644
--- a/src/lua/modules/keyboard/keyboard.cpp
+++ b/src/lua/modules/keyboard/keyboard.cpp
@@ -1,16 +1,16 @@
#include "lua/modules/luax.h"
-namespace jin
+namespace JinEngine
{
-namespace lua
-{
- //https://wiki.libsdl.org/SDL_Keycode
-
- int luaopen_keyboard(lua_State* L)
+ namespace Lua
{
- luax_newlib(L, 0);
- return 1;
- }
+ //https://wiki.libsdl.org/SDL_Keycode
+
+ int luaopen_keyboard(lua_State* L)
+ {
+ luax_newlib(L, 0);
+ return 1;
+ }
-} // lua
-} // jin \ No newline at end of file
+ } // Lua
+} // JinEngine \ No newline at end of file